@@ -204,7 +204,7 @@ void smplVec::rarefy(vector<double> depts, string ofile, int rep,
         DivEsts* divs, std::vector<vector<rare_map>> & RareSample,
         vector<string>& retCntsSampleName, string& skippedSample,
         vector<vector<vector<uint>>>* abundInRow, vector<vector<vector<uint>>>* occuencesInRow,
-        int writes,bool write, bool fillret){
+        int writes,bool write, bool fillret, uint seed){
     bool doShuffle = true;
     long curIdx = 0;
     long dep;
@@ -229,7 +229,7 @@ void smplVec::rarefy(vector<double> depts, string ofile, int rep,
         //long curIdx=(long)totSum+1;
         for (int curRep=0;curRep<rep;curRep++){
             if(curIdx+dep >= (long) totSum || doShuffle == true){
-                shuffle_singl();	
+                shuffle_singl(seed); 
                 curIdx = 0;
                 doShuffle = false;
             }
@@ -545,12 +545,17 @@ if (verbose){
 }
 }*/
 
-void smplVec::shuffle_singl() {
+void smplVec::shuffle_singl(unsigned int seed) {
     //auto engine = std::default_random_engine{};
 //    std::random_device rd;
 //    auto engine = std::mt19937_64{rd()};
-	unsigned long long seed = (unsigned long long)chrono::high_resolution_clock::now().time_since_epoch().count();
-	auto engine = std::mt19937_64{ seed };
+    unsigned long long seed_use;
+    if(seed == 0){
+        seed_use = (unsigned long long)chrono::high_resolution_clock::now().time_since_epoch().count();
+    }else{
+        seed_use = seed;
+    }
+	auto engine = std::mt19937_64{ seed_use };
     std::shuffle(std::begin(arr), std::end(arr), engine);	
 }
 
